package com.bpcl.lpg.core.cronjob;

import org.slf4j.LoggerFactory;
import de.hybris.platform.cronjob.model.CronJobModel;
import de.hybris.platform.core.model.media.MediaModel;
import de.hybris.platform.cronjob.enums.CronJobStatus;
import de.hybris.platform.cronjob.enums.CronJobResult;
import de.hybris.platform.servicelayer.util.ServicesUtil;
import de.hybris.platform.servicelayer.cronjob.PerformResult;
import com.bpcl.lpg.core.strategies.LPGConnectionImpexWriterStrategy;
import de.hybris.platform.servicelayer.media.MediaService;
import org.slf4j.Logger;
import com.bpcl.lpg.core.model.LPGConnectionExportCronjobModel;
import de.hybris.platform.servicelayer.cronjob.AbstractJobPerformable;

public class LPGConnectionImpexJob extends AbstractJobPerformable<LPGConnectionExportCronjobModel>
{
    private static final Logger LOG;
    private MediaService mediaService;
    private LPGConnectionImpexWriterStrategy lpgConnectionImpexWriterStrategy;
    
    public PerformResult perform(final LPGConnectionExportCronjobModel model) {
        LPGConnectionImpexJob.LOG.info(" ---------- Starting LPGConnection CSV creation process ----------");
        final String mediafileName = model.getMediaFileName();
        ServicesUtil.validateParameterNotNullStandardMessage("mediafileName", (Object)mediafileName);
        final MediaModel mediaModel = this.getMediaService().getMedia(mediafileName);
        boolean isSuccess = Boolean.FALSE;
        if (null == mediaModel) {
            return new PerformResult(CronJobResult.FAILURE, CronJobStatus.ABORTED);
        }
        isSuccess = this.getLpgConnectionImpexWriterStrategy().processCustomerCSVAndCreateLPGConnectionImpex(mediaModel, model);
        if (!isSuccess) {
            return new PerformResult(CronJobResult.FAILURE, CronJobStatus.ABORTED);
        }
        return new PerformResult(CronJobResult.SUCCESS, CronJobStatus.FINISHED);
    }
    
    public MediaService getMediaService() {
        return this.mediaService;
    }
    
    public void setMediaService(final MediaService mediaService) {
        this.mediaService = mediaService;
    }
    
    public LPGConnectionImpexWriterStrategy getLpgConnectionImpexWriterStrategy() {
        return this.lpgConnectionImpexWriterStrategy;
    }
    
    public void setLpgConnectionImpexWriterStrategy(final LPGConnectionImpexWriterStrategy lpgConnectionImpexWriterStrategy) {
        this.lpgConnectionImpexWriterStrategy = lpgConnectionImpexWriterStrategy;
    }
    
    static {
        LOG = LoggerFactory.getLogger(LPGConnectionImpexJob.class);
    }
}
